\name{MafDb.ALL.wgs.phase3.release.v5b.20130502}
\alias{MafDb.ALL.wgs.phase3.release.v5b.20130502-package}
\alias{MafDb.ALL.wgs.phase3.release.v5b.20130502}
\docType{package}

\title{
Annotation package for minor allele frequency data from the 1000 Genomes project
}
\description{
This annotation package stores minor allele frequency (MAF) data derived from the Phase 3 variant set of the 1000 Genomes project. The data is stored in the form of a SQLite database and is loaded automatically in the form of a MafDb object. The name of the exposed object matches the name of the package and part of the filename that contained the data imported into the package. The class definition and methods to access MafDb objects are found in the \code{\link[VariantFiltering]{VariantFiltering}} software package.
}

\format{
  \tabular{ll}{
    \code{\link{MafDb.ALL.wgs.phase3.release.v5b.20130502}} \tab MafDb object containing MAF values from the 1000 Genomes project downloaded in October 2015 from \url{ftp://ftp.1000genomes.ebi.ac.uk/vol1/ftp/release/20130502/ALL.wgs.phase3_shapeit2_mvncall_integrated_v5b.20130502.sites.vcf.gz}. See \code{\link{makeMafDbPackageKG}} for more information on how to update these data. \cr
  }
}

\author{
R. Castelo
}

\seealso{
  \link{makeMafDbPackageKG}
  \link[MafDb.ALL.wgs.phase1.release.v3.20101123]{MafDb.ALL.wgs.phase1.release.v3.20101123}
  \link[MafDb.ESP6500SI.V2.SSA137]{MafDb.ESP6500SI.V2.SSA137}
  \link[MafDb.ExAC.r0.3.sites]{MafDb.ExAC.r0.3.sites}
  \link[VariantFiltering]{MafDb-class}
  \link[VariantFiltering]{snpid2maf}
  \link[VariantFiltering]{VariantFiltering}
}

\examples{
library(MafDb.ALL.wgs.phase3.release.v5b.20130502)

ls("package:MafDb.ALL.wgs.phase3.release.v5b.20130502")

mafdb <- MafDb.ALL.wgs.phase3.release.v5b.20130502
mafdb

knownVariantsMAFcols(mafdb)

## lookup allele frequencies for rs1129038, a SNP associated to blue and brown eye colors
## as reported by Eiberg et al. Blue eye color in humans may be caused by a perfectly associated
## founder mutation in a regulatory element located within the HERC2 gene inhibiting OCA2 expression.
## Human Genetics, 123(2):177-87, 2008 [http://www.ncbi.nlm.nih.gov/pubmed/18172690]
snpid2maf(mafdb, "rs1129038")
}

\source{
  The 1000 Genomes Project Consortium. A global reference for human genetic variation.
  Nature, 526:68-74, 2015.
  (URL: \url{ftp://ftp.1000genomes.ebi.ac.uk}) [October, 2015, accessed]
}

\keyword{package}
\keyword{data}
